@@ -3,6 +3,7 @@ from logging import getLogger
 from django.db import models
 
 from pulpcore.plugin.models import (
+    AlternateContentSource,
     Content,
     Distribution,
     Publication,
@@ -28,6 +29,8 @@ class FileContent(Content):
         digest (str): The SHA256 HEX digest.
     """
 
+    PROTECTED_FROM_RECLAIM = False
+
     TYPE = "file"
     repo_key_fields = ("relative_path",)
 
@@ -124,7 +127,18 @@ class FileDistribution(Distribution):
     """
 
     TYPE = "file"
-    publication_based = True
+    SERVE_FROM_PUBLICATION = True
+
+    class Meta:
+        default_related_name = "%(app_label)s_%(model_name)s"
+
+
+class FileAlternateContentSource(AlternateContentSource):
+    """
+    Alternate Content Source for 'file" content.
+    """
+
+    TYPE = "file"
 
     class Meta:
         default_related_name = "%(app_label)s_%(model_name)s"
