@@ -9,6 +9,7 @@ from pulpcore.plugin.serializers import (
 )
 from pulpcore.plugin.tasking import dispatch
 from pulpcore.plugin.viewsets import (
+    AlternateContentSourceViewSet,
     ContentFilter,
     DistributionViewSet,
     OperationPostponedResponse,
@@ -21,6 +22,7 @@ from pulpcore.plugin.viewsets import (
 
 from . import tasks
 from .models import (
+    FileAlternateContentSource,
     FileContent,
     FileDistribution,
     FileRemote,
@@ -28,6 +30,7 @@ from .models import (
     FilePublication,
 )
 from .serializers import (
+    FileAlternateContentSourceSerializer,
     FileContentSerializer,
     FileDistributionSerializer,
     FileRemoteSerializer,
@@ -41,7 +44,7 @@ class FileContentFilter(ContentFilter):
     FilterSet for FileContent.
     """
 
-    sha256 = CharFilter(field_name="_artifacts__sha256")
+    sha256 = CharFilter(field_name="digest")
 
     class Meta:
         model = FileContent
@@ -178,3 +181,15 @@ class FileDistributionViewSet(DistributionViewSet):
     endpoint_name = "file"
     queryset = FileDistribution.objects.all()
     serializer_class = FileDistributionSerializer
+
+
+class FileAlternateContentSourceViewSet(AlternateContentSourceViewSet):
+    """
+    Alternate Content Source ViewSet for File
+
+    ACS support is provided as a tech preview in pulp_file.
+    """
+
+    endpoint_name = "file"
+    queryset = FileAlternateContentSource.objects.all()
+    serializer_class = FileAlternateContentSourceSerializer
