@@ -3,10 +3,9 @@
 from random import choice
 import unittest
 
-from pulp_smash.pulp3.bindings import monitor_task
+from pulp_smash.pulp3.bindings import delete_orphans, monitor_task
 from pulp_smash.pulp3.constants import ON_DEMAND_DOWNLOAD_POLICIES
 from pulp_smash.pulp3.utils import (
-    delete_orphans,
     gen_repo,
     get_added_content_summary,
     get_content_summary,
